@@ -714,7 +714,10 @@ def _get_freeze_source_packages(
     return source_package_names
 
 
-def get_package_requirements(package_name: str) -> Iterable[str]:
+def get_package_requirements(
+    package_name: str,
+    recursive: bool = True
+) -> Iterable[str]:
     # Get the output of `pip show`
     status: int
     output: str
@@ -726,13 +729,24 @@ def get_package_requirements(package_name: str) -> Iterable[str]:
         if line.startswith('Requires:'):
             required_package_name: str
             for required_package_name in line[9:].lstrip().split(','):
-                yield required_package_name.strip().replace('_', '-')
+                required_package_name = required_package_name.strip().replace(
+                    '_', '-'
+                )
+                if required_package_name:
+                    if recursive:
+                        required_package_depencency_name: str
+                        for required_package_depencency_name in (
+                            get_package_requirements(required_package_name)
+                        ):
+                            yield required_package_depencency_name
+                    yield required_package_name
             break
 
 
 def get_freeze(
     editable: bool = False,
-    exclude: Union[str, Collection[str]] = ()
+    exclude: Union[str, Collection[str]] = (),
+    include: Union[str, Collection[str]] = ()
 ) -> Iterable[str]:
     """
     Iterate over the packages installed/referenced in the current environment.
